==> tab_title_attention-1.0.0.tar.gz: tab_title_attention/tests/src/FunctionalJavascript/TabTitleAttentionJavascriptTest.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\tab_title_attention\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests the JavaScript functionality of the Tab Title Attention module.
 *
 * @group tab_title_attention
 */
final class TabTitleAttentionJavascriptTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['tab_title_attention'];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests wether the settings are saved and applied via drupalSettings.
   */
  public function testSettings(): void {
    // Since the animation is disabled by default, check the drupalSettings to
    // make sure that the library is not yet injected.
    $driver = $this->getSession()->getDriver();
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNull($drupalSettings);
    // Go to the settings page and check if the default settings are present.
    $this->drupalGet('/admin/config/user-interface/tab-title-attention');
    $session = $this->assertSession();
    $session->checkboxNotChecked('active');
    $session->fieldValueEquals('delay', 500);
    $session->fieldValueEquals('message', "Don't forget about this tab!");
    $session->fieldValueEquals('animation', 'static');
    $session->fieldValueEquals('speed', 1000);
    // Change the settings and check if they apply after save.
    $page = $this->getSession()->getPage();
    $page->checkField('active');
    $page->fillField('delay', 123);
    $page->fillField('message', 'Test Message!');
    $page->fillField('animation', 'scroll');
    $page->fillField('speed', 456);
    $page->pressButton('edit-submit');
    $session->checkboxChecked('active');
    $session->fieldValueEquals('delay', 123);
    $session->fieldValueEquals('message', 'Test Message!');
    $session->fieldValueEquals('animation', 'scroll');
    $session->fieldValueEquals('speed', 456);
    // Check the drupalSettings in JS to see if the settings also apply there.
    $settingActive = $driver->evaluateScript('drupalSettings.tab_title_attention.active');
    $settingDelay = $driver->evaluateScript('drupalSettings.tab_title_attention.delay');
    $settingMessage = $driver->evaluateScript('drupalSettings.tab_title_attention.message');
    $settingAnimation = $driver->evaluateScript('drupalSettings.tab_title_attention.animation');
    $settingSpeed = $driver->evaluateScript('drupalSettings.tab_title_attention.speed');
    $this->assertTrue($settingActive);
    $this->assertEquals(123, $settingDelay);
    $this->assertEquals('Test Message!', $settingMessage);
    $this->assertEquals('scroll', $settingAnimation);
    $this->assertEquals(456, $settingSpeed);
  }

  /**
   * Tests all of the module permissions.
   */
  public function testPermissions(): void {
    // Go to the settings page and activate the animation.
    $this->drupalGet('/admin/config/user-interface/tab-title-attention');
    $page = $this->getSession()->getPage();
    $page->checkField('active');
    $page->pressButton('edit-submit');
    // Check that, as the admin user, the library is now injected.
    $driver = $this->getSession()->getDriver();
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNotNull($drupalSettings);
    // Log in as a regular user without the permission to see the animation and
    // check that the library is not injected anymore.
    $this->drupalLogout();
    $this->drupalLogin($this->user);
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNull($drupalSettings);
    // Now also go to the settings page and see that it returns a 403.
    $this->drupalGet('/admin/config/user-interface/tab-title-attention');
    $session = $this->assertSession();
    $session->pageTextContains('Access denied');
  }

}

==> tab_title_attention-1.0.1.tar.gz: tab_title_attention/tests/src/FunctionalJavascript/TabTitleAttentionJavascriptTest.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\tab_title_attention\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests the JavaScript functionality of the Tab Title Attention module.
 *
 * @group tab_title_attention
 */
final class TabTitleAttentionJavascriptTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['tab_title_attention'];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests wether the settings are saved and applied via drupalSettings.
   */
  public function testSettings(): void {
    // Since the animation is disabled by default, check the drupalSettings to
    // make sure that the library is not yet injected.
    $driver = $this->getSession()->getDriver();
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNull($drupalSettings);
    // Go to the settings page and check if the default settings are present.
    $this->drupalGet('/admin/config/user-interface/tab-title-attention');
    $session = $this->assertSession();
    $session->checkboxNotChecked('active');
    $session->fieldValueEquals('delay', 5000);
    $session->fieldValueEquals('message', "Don't forget about this tab!");
    $session->fieldValueEquals('animation', 'blink');
    $session->fieldValueEquals('speed', 4000);
    // Change the settings and check if they apply after save.
    $page = $this->getSession()->getPage();
    $page->checkField('active');
    $page->fillField('delay', 123);
    $page->fillField('message', 'Test Message!');
    $page->fillField('animation', 'scroll');
    $page->fillField('speed', 456);
    $page->pressButton('edit-submit');
    $session->checkboxChecked('active');
    $session->fieldValueEquals('delay', 123);
    $session->fieldValueEquals('message', 'Test Message!');
    $session->fieldValueEquals('animation', 'scroll');
    $session->fieldValueEquals('speed', 456);
    // Check the drupalSettings in JS to see if the settings also apply there.
    $this->drupalGet('<front>');
    $settingActive = $driver->evaluateScript('drupalSettings.tab_title_attention.active');
    $settingDelay = $driver->evaluateScript('drupalSettings.tab_title_attention.delay');
    $settingMessage = $driver->evaluateScript('drupalSettings.tab_title_attention.message');
    $settingAnimation = $driver->evaluateScript('drupalSettings.tab_title_attention.animation');
    $settingSpeed = $driver->evaluateScript('drupalSettings.tab_title_attention.speed');
    $this->assertTrue($settingActive);
    $this->assertEquals(123, $settingDelay);
    $this->assertEquals('Test Message!', $settingMessage);
    $this->assertEquals('scroll', $settingAnimation);
    $this->assertEquals(456, $settingSpeed);
  }

  /**
   * Tests all of the module permissions.
   */
  public function testPermissions(): void {
    $driver = $this->getSession()->getDriver();
    // Go to the settings page and activate the animation.
    $this->drupalGet('/admin/config/user-interface/tab-title-attention');
    $page = $this->getSession()->getPage();
    $page->checkField('active');
    $page->pressButton('edit-submit');

    // By defaultconditions, admin pages should be excluded:
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNull($drupalSettings);

    // Check that, as the admin user, the library is now injected:
    $this->drupalGet('<front>');
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNotNull($drupalSettings);
    // Log in as a regular user without the permission to see the animation and
    // check that the library is not injected anymore.
    $this->drupalLogout();
    $this->drupalLogin($this->user);
    $this->drupalGet('<front>');
    $drupalSettings = $driver->evaluateScript('drupalSettings.tab_title_attention');
    $this->assertNull($drupalSettings);
    // Now also go to the settings page and see that it returns a 403.
    $this->drupalGet('/admin/config/user-interface/tab-title-attention');
    $session = $this->assertSession();
    $session->pageTextContains('Access denied');
  }

}
